# Changelog

## 0.3.0 (2026-01-30)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/y2-intel/y2-py/compare/v0.2.0...v0.3.0)

### Features

* **client:** add custom JSON encoder for extended type support ([e85356a](https://github.com/y2-intel/y2-py/commit/e85356a381475ffbe08fb959284ecb2d571f0aff))
* **client:** add support for binary request streaming ([a8f65b3](https://github.com/y2-intel/y2-py/commit/a8f65b35488abe14d21442ab57d99f7885949d21))


### Chores

* **ci:** upgrade `actions/github-script` ([897862a](https://github.com/y2-intel/y2-py/commit/897862a888389466e8b43b5c8b768f1c5537b196))
* **internal:** codegen related update ([38f3008](https://github.com/y2-intel/y2-py/commit/38f30086f2f78de68b56799d36b0aefed9ea557c))
* **internal:** update `actions/checkout` version ([61ea208](https://github.com/y2-intel/y2-py/commit/61ea2080efa36f79ebf6c2962b8e0f29183e8fde))

## 0.2.0 (2025-12-31)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/y2-intel/y2-py/compare/v0.1.0...v0.2.0)

### Features

* **api:** manual updates ([32aa037](https://github.com/y2-intel/y2-py/commit/32aa0375b37f757ecf4e55769f9883b28006d647))

## 0.1.0 (2025-12-28)

Full Changelog: [v0.0.3...v0.1.0](https://github.com/y2-intel/y2-py/compare/v0.0.3...v0.1.0)

### Features

* **api:** manual updates ([2a311cd](https://github.com/y2-intel/y2-py/commit/2a311cd4dd379409836ea539244f742128c5b4e4))

## 0.0.3 (2025-12-26)

Full Changelog: [v0.0.2...v0.0.3](https://github.com/y2-intel/y2-py/compare/v0.0.2...v0.0.3)

### Chores

* update SDK settings ([86d94f7](https://github.com/y2-intel/y2-py/commit/86d94f730719ad9c2be47e1c1fde598fb88eebc2))

## 0.0.2 (2025-12-24)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/y2-intel/y2-py/compare/v0.0.1...v0.0.2)

### Chores

* update SDK settings ([199b21a](https://github.com/y2-intel/y2-py/commit/199b21aa7a34f9a5489fa593a764afa8c7097248))
* update SDK settings ([9d60021](https://github.com/y2-intel/y2-py/commit/9d600214561cf0b69254a5b20783bef26ee6f34f))
